<?php

namespace Litecms\Payout\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Payout\Models\Payout;

class PayoutPolicy
{

    /**
     * Determine if the given user can view the payout.
     *
     * @param UserPolicy $user
     * @param Payout $payout
     *
     * @return bool
     */
    public function view(UserPolicy $user, Payout $payout)
    {
        if ($user->canDo('payout.payout.view') && $user->isAdmin()) {
            return true;
        }

        return $payout->user_id == user_id() && $payout->user_type == user_type();
    }

    /**
     * Determine if the given user can create a payout.
     *
     * @param UserPolicy $user
     * @param Payout $payout
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('payout.payout.create');
    }

    /**
     * Determine if the given user can update the given payout.
     *
     * @param UserPolicy $user
     * @param Payout $payout
     *
     * @return bool
     */
    public function update(UserPolicy $user, Payout $payout)
    {
        if ($user->canDo('payout.payout.edit') && $user->isAdmin()) {
            return true;
        }

        return $payout->user_id == user_id() && $payout->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given payout.
     *
     * @param UserPolicy $user
     * @param Payout $payout
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Payout $payout)
    {
        return $payout->user_id == user_id() && $payout->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given payout.
     *
     * @param UserPolicy $user
     * @param Payout $payout
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Payout $payout)
    {
        if ($user->canDo('payout.payout.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given payout.
     *
     * @param UserPolicy $user
     * @param Payout $payout
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Payout $payout)
    {
        if ($user->canDo('payout.payout.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
